==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property audioFramesPerPes
 * @property audioPids
 * @property ecmPid
 * @property nielsenId3Behavior
 * @property patInterval
 * @property pcrControl
 * @property pcrPeriod
 * @property pcrPid
 * @property pmtInterval
 * @property pmtPid
 * @property programNum
 * @property scte35Behavior
 * @property scte35Pid PID from which to read SCTE-35 messages.
 * @property timedMetadataBehavior
 * @property timedMetadataPid
 * @property transportStreamId
 * @property videoPid
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings(
    public val audioFramesPerPes: Int? = null,
    public val audioPids: String? = null,
    public val ecmPid: String? = null,
    public val nielsenId3Behavior: String? = null,
    public val patInterval: Int? = null,
    public val pcrControl: String? = null,
    public val pcrPeriod: Int? = null,
    public val pcrPid: String? = null,
    public val pmtInterval: Int? = null,
    public val pmtPid: String? = null,
    public val programNum: Int? = null,
    public val scte35Behavior: String? = null,
    public val scte35Pid: String? = null,
    public val timedMetadataBehavior: String? = null,
    public val timedMetadataPid: String? = null,
    public val transportStreamId: Int? = null,
    public val videoPid: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings):
            ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings =
            ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings(
                audioFramesPerPes = javaType.audioFramesPerPes().map({ args0 -> args0 }).orElse(null),
                audioPids = javaType.audioPids().map({ args0 -> args0 }).orElse(null),
                ecmPid = javaType.ecmPid().map({ args0 -> args0 }).orElse(null),
                nielsenId3Behavior = javaType.nielsenId3Behavior().map({ args0 -> args0 }).orElse(null),
                patInterval = javaType.patInterval().map({ args0 -> args0 }).orElse(null),
                pcrControl = javaType.pcrControl().map({ args0 -> args0 }).orElse(null),
                pcrPeriod = javaType.pcrPeriod().map({ args0 -> args0 }).orElse(null),
                pcrPid = javaType.pcrPid().map({ args0 -> args0 }).orElse(null),
                pmtInterval = javaType.pmtInterval().map({ args0 -> args0 }).orElse(null),
                pmtPid = javaType.pmtPid().map({ args0 -> args0 }).orElse(null),
                programNum = javaType.programNum().map({ args0 -> args0 }).orElse(null),
                scte35Behavior = javaType.scte35Behavior().map({ args0 -> args0 }).orElse(null),
                scte35Pid = javaType.scte35Pid().map({ args0 -> args0 }).orElse(null),
                timedMetadataBehavior = javaType.timedMetadataBehavior().map({ args0 -> args0 }).orElse(null),
                timedMetadataPid = javaType.timedMetadataPid().map({ args0 -> args0 }).orElse(null),
                transportStreamId = javaType.transportStreamId().map({ args0 -> args0 }).orElse(null),
                videoPid = javaType.videoPid().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property audioFramesPerPes
 * @property audioPids
 * @property ecmPid
 * @property nielsenId3Behavior
 * @property patInterval
 * @property pcrControl
 * @property pcrPeriod
 * @property pcrPid
 * @property pmtInterval
 * @property pmtPid
 * @property programNum
 * @property scte35Behavior
 * @property scte35Pid PID from which to read SCTE-35 messages.
 * @property timedMetadataBehavior
 * @property timedMetadataPid
 * @property transportStreamId
 * @property videoPid
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings(
    public val audioFramesPerPes: Int? = null,
    public val audioPids: String? = null,
    public val ecmPid: String? = null,
    public val nielsenId3Behavior: String? = null,
    public val patInterval: Int? = null,
    public val pcrControl: String? = null,
    public val pcrPeriod: Int? = null,
    public val pcrPid: String? = null,
    public val pmtInterval: Int? = null,
    public val pmtPid: String? = null,
    public val programNum: Int? = null,
    public val scte35Behavior: String? = null,
    public val scte35Pid: String? = null,
    public val timedMetadataBehavior: String? = null,
    public val timedMetadataPid: String? = null,
    public val transportStreamId: Int? = null,
    public val videoPid: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings): ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings =
            ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettingsStandardHlsSettingsM3u8Settings(
                audioFramesPerPes = javaType.audioFramesPerPes().map({ args0 -> args0 }).orElse(null),
                audioPids = javaType.audioPids().map({ args0 -> args0 }).orElse(null),
                ecmPid = javaType.ecmPid().map({ args0 -> args0 }).orElse(null),
                nielsenId3Behavior = javaType.nielsenId3Behavior().map({ args0 -> args0 }).orElse(null),
                patInterval = javaType.patInterval().map({ args0 -> args0 }).orElse(null),
                pcrControl = javaType.pcrControl().map({ args0 -> args0 }).orElse(null),
                pcrPeriod = javaType.pcrPeriod().map({ args0 -> args0 }).orElse(null),
                pcrPid = javaType.pcrPid().map({ args0 -> args0 }).orElse(null),
                pmtInterval = javaType.pmtInterval().map({ args0 -> args0 }).orElse(null),
                pmtPid = javaType.pmtPid().map({ args0 -> args0 }).orElse(null),
                programNum = javaType.programNum().map({ args0 -> args0 }).orElse(null),
                scte35Behavior = javaType.scte35Behavior().map({ args0 -> args0 }).orElse(null),
                scte35Pid = javaType.scte35Pid().map({ args0 -> args0 }).orElse(null),
                timedMetadataBehavior = javaType.timedMetadataBehavior().map({ args0 -> args0 }).orElse(null),
                timedMetadataPid = javaType.timedMetadataPid().map({ args0 -> args0 }).orElse(null),
                transportStreamId = javaType.transportStreamId().map({ args0 -> args0 }).orElse(null),
                videoPid = javaType.videoPid().map({ args0 -> args0 }).orElse(null),
            )
    }
}
